import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { ButtonProps } from '@highlight-ui/button';
export declare type ActionButtonProps = PropsWithMetadata<{
    label: string;
    onClick?: () => void;
    buttonState?: ButtonProps['buttonState'];
    type?: ButtonProps['type'];
    tone?: ButtonProps['tone'];
}>;
export declare type ActionBarProps = PropsWithMetadata<{
    /** Allows rendering any element on the left side of the ActionBar. If specified, the action buttons will be aligned to the right. */
    information?: React.ReactNode;
    /** Allows providing a custom class name */
    className?: string;
    /** When `inline`, uses `position: sticky` to position the ActionBar and uses `100%` of its container's width. When `full-width`, uses `position: fixed` to position the ActionBar and uses `100% - 64px` (unless used in combination with `elementQuerySelector` prop - check for more info) of its container's width. */
    variant: 'full-width' | 'inline';
    /** Allows passing props to the primary action button */
    primaryAction: ActionButtonProps;
    /** Allows passing props to the secondary action button */
    secondaryAction?: Omit<ActionButtonProps, 'type'>;
    /** Used only when `variant="full-width"` is selected. HTML element with transitionend addEventListener which querySelector calculates width from, example: '[data-test-id="navsidebar-container"]'.  */
    elementQuerySelector?: string;
}>;
declare const ActionBar: ({ primaryAction, secondaryAction, information, metadata, className, variant, elementQuerySelector, }: ActionBarProps) => JSX.Element;
export default ActionBar;
